<?php

#-------------------------------------------------------------------------
# Module: OwnersManual
# Author: Wishbone <wayne@teamwishbone.com>
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#-------------------------------------------------------------------------
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#-------------------------------------------------------------------------
#END_LICENSE

$cgextensions = cms_join_path($gCms->config['root_path'],'modules',
                  'CGExtensions','CGExtensions.module.php');
if( !is_readable( $cgextensions ) )
{
  echo '<h1><font color="red">ERROR: The CGExtensions module could not be found.</font></h1>';
  return;
}
require_once($cgextensions);

class OwnersManual extends CGExtensions {
  var $MANUAL_TABLE;

  function OwnersManual() {
    parent::CMSModule();
    $this->MANUAL_TABLE = cms_db_prefix() . 'module_OwnersManual_manual';
  }

  function GetName() {
    return 'OwnersManual';
  }
  
  function GetFriendlyName() {
    return htmlspecialchars($this->GetPreference('module_name', $this->Lang('friendlyname')));
  }

  function GetVersion() {
    return '1.0.2';
  }
  
  function GetHelp() {
      return file_get_contents(dirname(__FILE__).'/help.inc');
  }
  
  function GetAuthor() {
    return 'Wishbone';
  }

  function GetAuthorEmail() {
    return 'wayne@teamwishbone.com';
  }
  
  function GetChangeLog() {
      return file_get_contents(dirname(__FILE__).'/changelog.inc');
  }
  
  function IsPluginModule() {
    return false;
  }

  function HasAdmin() {
    return true;
  }

  function GetAdminSection() {
    return('main');
  }

  function GetAdminDescription() {
    return $this->Lang('moddescription');
  }

  function VisibleToAdminUser() {
    return $this->CheckPermission('View OwnersManual');
  }
  
  function GetDependencies() {
    return array('CGExtensions'=>'1.19.1');
  }

  function MinimumCMSVersion() {
    return "1.8.1";
  }
  
  function SetParameters() {
    $this->RestrictUnknownParams();
  }

  function InstallPostMessage() {
    return $this->Lang('postinstall');
  }

  function UninstallPostMessage() {
    return $this->Lang('postuninstall');
  }

  function UninstallPreMessage() {
    return $this->Lang('really_uninstall');
  }

  function AdminStyle() {
    return '#man_content_div li {list-style: disc outside none; width: 100%}';
  }
}
?>
